% AMOC_2016.m
% Computes trends from large ensemble for exactly observational period. 
% Must be invoked from the AMOC trend part of leg.m.
% Copyright Jochem Marotzke, MPI-M, 3 August 2016. Updated for period 
% up to 2016 (daily obs Feb 2017), 3 Jan 2018.
%
%
% AMOC trend calculation for RCP2.6 and RCP4.5

 trend_2016_RCP2_6=zeros(100,2); trend_2016_RCP4_5=zeros(100,2); % Pre-allocate

% Loop over realisations:
 for ir=1:100
     trend_2016_RCP2_6(ir,:)=polyfit([2004:1:2016],...
         [amoc26N_hist(ir,end-1:end), amoc26N_RCP2_6(ir,1:11)],1);
     trend_2016_RCP2_6(ir,1)=10*trend_2016_RCP2_6(ir,1);
     trend_2016_RCP4_5(ir,:)=polyfit([2004:1:2016],...
         [amoc26N_hist(ir,end-1:end), amoc26N_RCP4_5(ir,1:11)],1);
     trend_2016_RCP4_5(ir,1)=10*trend_2016_RCP4_5(ir,1);
 end


 figure(98), clf reset
 set(gcf, 'PaperOrientation', 'landscape')
 set(gcf, 'PaperPosition', [.5 .5 27 19]);
 set(gcf, 'PaperPosition', [.5 8 27 8]);
 xmin=-5.5; xmax=5.5; ymin=0; ymax=14.5;

 subplot(1,3,1)
 binranges=[-7:.25:7];
 trendcount_2016_RCP2_6=histc(trend_2016_RCP2_6(:,1),binranges);
 hb=bar(binranges,trendcount_2016_RCP2_6,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hold on
 hl=line([MOC_mar_hc10_trend MOC_mar_hc10_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'RAPID trend, 2004-2016');
 title('AMOC26N trend 2004-2016, RCP2.6')
 xlabel('Sv per decade')
 
 subplot(1,3,2)
 trendcount_2016_RCP4_5=histc(trend_2016_RCP4_5(:,1),binranges);
 hb=bar(binranges,trendcount_2016_RCP4_5,'histc');
 set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
 axis([xmin xmax ymin ymax])
 hold on
 hl=line([MOC_mar_hc10_trend MOC_mar_hc10_trend],[ymin ymax],'color',...
     [33 143 118]./255,'linewidth',3);
 legend(hl,'RAPID trend, 2004-2016');
%  title('AMOC26N trend 2004-2016, RCP4.5')
 title('RCP4.5')
 xlabel('Sv per decade')
 
%  subplot(1,3,3)
%  trend_diff=trend_2016_RCP2_6-trend_2016_RCP4_5;
%  trendcount_diff=histc(trend_diff(:,1),binranges);
%  hb=bar(binranges,trendcount_diff,'histc');
%  set(hb,'facecolor',[0.9287  0.9287 0.7692])    % from the Pink colormap
%  hold on
%  hl=line([0 0],[ymin ymax],'color','k','linestyle',':'); 
%  axis([xmin xmax ymin ymax])
%  title('Change in AMOC26N trend, 2035 vs. 2020, RCP2.6')
%  title('Difference, RCP2.6--RCP4.6')
%  xlabel('Sv per decade')

 trend_diff_sort=sort(trend_diff);
 ifast_AMOC26N_2016=find(trend_diff_sort>0,1,'first')
 
 print -dpdf 'AMOC26N_trends_2016_RCP2_6_RCP4_5.pdf'


 